<?php
/**
 * expertio functions and definitions
 *
 * @link https://themeforest.net/user/amentotech/portfolio
 *
 * @package expertio
 */

if ( ! defined( 'THEME_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'THEME_VERSION', '1.0.0' );
}

require_once ( get_template_directory() . '/inc/tgmp/init.php'); //TGM init

if ( ! function_exists( 'expertio_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function expertio_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on expertio, use a find and replace
		 * to change 'expertio' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'expertio', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'primary-menu' 	=> esc_html__( 'Primary menu', 'expertio' ),
				'footer-menu' 	=> esc_html__( 'Footer menu', 'expertio' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption'
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'expertio_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		add_theme_support( 'custom-logo', array(
			'height' => 200,
			'width'  => 200,
		) );

		
		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/*
		* Enable support for Post Formats.  
		* See http://codex.wordpress.org/Post_Formats     
		*/
		add_theme_support('post-formats' , array (
			''
		));
		
		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );
}
endif;
add_action( 'after_setup_theme', 'expertio_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
if(!function_exists('expertio_content_width')){
	function expertio_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'expertio_content_width', 1296 );
	}
	add_action( 'after_setup_theme', 'expertio_content_width', 0 );
}

/**
 * Register widget area.
 *
 * @link https://themeforest.net/user/amentotech/portfolio
 */
if(!function_exists('expertio_widgets_init')){
	function expertio_widgets_init() {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Default sidebar', 'expertio' ),
				'id'            => 'expertio-sidebar',
				'description'   => esc_html__( 'Default archive side', 'expertio' ),
				'before_widget' => '<div id="%1$s" class="%2$s tk-widgetbox">',
				'after_widget'  => '</div>',
				'before_title'  => '<h5>',
				'after_title'   => '</h5>',
			)
		);

		register_sidebar(
			array(
				'name'          => esc_html__( 'Single post sidebar', 'expertio' ),
				'id'            => 'expertio-single-sidebar',
				'description'   => esc_html__( 'Single post sidebar', 'expertio' ),
				'before_widget' => '<div id="%1$s" class="%2$s tk-widgetbox">',
				'after_widget'  => '</div>',
				'before_title'  => '<h5>',
				'after_title'   => '</h5>',
			)
		);
		
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer sidebar 1', 'expertio' ),
				'id'            => 'expertio-sidebar-f1',
				'description'   => esc_html__( 'For footer first section', 'expertio' ),
				'before_widget' => '<div id="%1$s" class="%2$s tk-widgetbox">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="tk-sidetitle"><h5>',
				'after_title'   => '</h5></div>',
			)
		);
		
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer sidebar 2', 'expertio' ),
				'id'            => 'expertio-sidebar-f2',
				'description'   => esc_html__( 'For footer second column', 'expertio' ),
				'before_widget' => '<div id="%1$s" class="%2$s tk-widgetbox">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="tk-sidetitle"><h5>',
				'after_title'   => '</h5></div>',
			)
		);
		
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer sidebar 3', 'expertio' ),
				'id'            => 'expertio-sidebar-f3',
				'description'   => esc_html__( 'For footer third column', 'expertio' ),
				'before_widget' => '<div id="%1$s" class="%2$s tk-widgetbox">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="tk-sidetitle"><h5>',
				'after_title'   => '</h5></div>',
			)
		);
	}
	add_action( 'widgets_init', 'expertio_widgets_init' );
}

/**
 * Enqueue scripts and styles.
 */
if(!function_exists('expertio_scripts')){
	function expertio_scripts() {
		global $servento_settings;
		$header_search	= !empty($servento_settings['header_search']) ? $servento_settings['header_search'] : false;
		$loading_duration	= !empty($servento_settings['loading_duration']) ? $servento_settings['loading_duration'] : 500;
		$theme_version 		= wp_get_theme('expertio');
		
		//register css
		wp_register_style('bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', array(), $theme_version->get('Version'));
		wp_register_style( 'feather-icons', get_template_directory_uri(). '/css/feather-icons.css', array(),$theme_version->get('Version'), 'all' );
		wp_register_style( 'fontawesome', get_template_directory_uri(). '/css/fontawesome/all.min.css', array(), $theme_version->get('Version'), 'all' );
		wp_register_style( 'expertio-style', get_stylesheet_uri(), array(), $theme_version->get('Version') );
		wp_register_style( 'select2', get_template_directory_uri() . '/css/select2.min.css',  array(), $theme_version->get('Version'));
		wp_register_style( 'expertio-rtl-styles', get_template_directory_uri() . '/css/rtl.css',  array(), $theme_version->get('Version'));
		wp_register_style( 'expertio-responsive', get_template_directory_uri() . '/css/responsive.css',  array(), $theme_version->get('Version'));

		//register js
		wp_register_script( 'bootstrap', get_template_directory_uri() . '/js/vendor/bootstrap.min.js', array( 'jquery' ), $theme_version->get('Version'), true );
		wp_register_script( 'select2', get_template_directory_uri() . 'js/vendor/select2.min.js', array(), $theme_version->get('Version'), true );
		wp_register_script( 'expertio-callbacks', get_template_directory_uri() . '/js/callbacks.js', array('jquery'), $theme_version->get('Version'), true );
		
		
		//css enqueue
		wp_enqueue_style('bootstrap');
		if( !empty($header_search) ){
			wp_enqueue_style('select2');
		}

		wp_enqueue_style('expertio-normalize');
		wp_enqueue_style('feather-icons');
		wp_enqueue_style('fontawesome');
		wp_enqueue_style('expertio-style');
		wp_enqueue_style('expertio-responsive');
		if ( is_rtl() ) {wp_enqueue_style( 'expertio-rtl-styles' );}

		//js enqueue
		if( !empty($header_search) ){
			wp_enqueue_script('select2');
		}
		wp_enqueue_script('bootstrap');
		wp_enqueue_script('expertio-callbacks');

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		wp_localize_script('expertio-callbacks', 'expertio_vars', array(
			'loading_duration'			=> $loading_duration,
            'ajaxurl'					=> admin_url('admin-ajax.php'),
        ));
	}
	add_action( 'wp_enqueue_scripts', 'expertio_scripts' );
}

/**
 * @Enque Google Font
 * @return
 */
if (!function_exists('expertio_enqueue_google_fonts')) {
    function expertio_enqueue_google_fonts() {
		$protocol = is_ssl() ? 'https' : 'http';
		
		//Default theme font famlies
		$font_families	= array();
		$font_families[] = 'Outfit:400,500,600,700';
		$font_families[] = 'Open+Sans:400,600,700';
		
		 $query_args = array (
			 'family' => implode('%7C' , $font_families) ,
			 'subset' => 'latin,latin-ext' ,
        );

        $theme_fonts = add_query_arg($query_args , $protocol.'://fonts.googleapis.com/css');

		wp_enqueue_style('expertio-default-google-fonts' , esc_url_raw($theme_fonts), array () , null);
    }
    add_action('wp_enqueue_scripts' , 'expertio_enqueue_google_fonts');
}

/**
 * Include files
 */
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/template-functions.php';
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

