<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package expertio
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
if (!function_exists('expertio__excerpt_length')) {
	function expertio__excerpt_length( $length=22 ) {
		return 22;
	}
	add_filter( 'excerpt_length', 'expertio__excerpt_length', 999 );
}

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
if (!function_exists('expertio_excerpt_more')) {
	function expertio_excerpt_more( $more='' ) {
		return '';
	}
	add_filter( 'excerpt_more', 'expertio_excerpt_more' );
}

if (!function_exists('expertio_body_classes')) {
	function expertio_body_classes( $classes ) {
		// Adds a class of hfeed to non-singular pages.
		if ( ! is_singular() ) {
			$classes[] = 'hfeed';
		}

		// Adds a class of no-sidebar when there is no sidebar present.
		if ( ! is_active_sidebar( 'expertio-sidebar' ) ) {
			$classes[] = 'no-sidebar';
		}

		return $classes;
	}
	add_filter( 'body_class', 'expertio_body_classes' );
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
if (!function_exists('expertio_pingback_header')) {
	function expertio_pingback_header() {
		if ( is_singular() && pings_open() ) {
			printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
		}
	}
	add_action( 'wp_head', 'expertio_pingback_header' );
}


/**
 * Pangination
 *
 * @return
 * @throws error
 * @author Amentotech <theamentotech@gmail.com>
 */
if (!function_exists('expertio_pagination')) {
  function expertio_pagination($expertio_query= '', $class= ''){
	global $wp_query;
	$expertio_total = $wp_query->max_num_pages;
	  
    if ($expertio_total > 1) {
      if( !empty($class)){ ?>
        <div class="<?php echo esc_attr($class);?>">
      <?php } ?>
      <div class="tk-pagination">
        <?php
          echo paginate_links(array(
            'base'         => str_replace(999999999, '%#%', esc_url_raw(get_pagenum_link(999999999))),
            'total'        => $expertio_total,
            'current'      => max(1, get_query_var('paged')),
            'format'       => '?paged=%#%',
            'show_all'     => false,
            'type'         => 'list',
            'end_size'     => 2,
            'mid_size'     => 1,
            'prev_next'    => true,
            'prev_text'    => sprintf('<i class="icon-chevron-left"></i>'),
            'next_text'    => sprintf('<i class="icon-chevron-right"></i>'),
            'add_args'     => false,
            'add_fragment' => '',
          ));
        ?>
      </div>
 	 <?php
      if( !empty($class)){ ?>
        </div>
      <?php
      }
    }
  }
}

/**
 * comments listings
 * @return slug
 */
if (!function_exists('expertio_comments')) {

    function expertio_comments($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	$args['reply_text'] = esc_html__('Reply','expertio');
    $post_author_id		= get_the_author_meta('ID');
	$url    = get_author_posts_url($post_author_id);
	
	
	$empty_avatar = '';
	if(empty(get_avatar($comment, 100))){
		$empty_avatar = 'tk-empty-avatar';
	}
	?>
	<li <?php comment_class('comment-entry clearfix '.$empty_avatar); ?> id="comment-<?php comment_ID(); ?>">
		<div class="tk-addcomment">
            <div class="tk-blogimg">
    			<?php if(!empty(get_avatar($comment, 100))){?><figure><?php echo get_avatar($comment, 100); ?> </figure><?php }?>
    			<div class="tk-blogcmntinfo">
					<div class="tk-blogcmntinfonames">
						<div class="tk-icondetails"><span><?php echo sprintf( _x( '%s ago', '%s = human-readable time difference', 'expertio' ), human_time_diff( get_comment_time( 'U' ), current_time( 'timestamp' ) ) ); ?></span></div>
						<div class="tk-comentinfodetail">
                            <h4><a href="<?php echo esc_url( $url ); ?>"><?php comment_author(); ?></a></h4>
						</div>
					</div>
   					<div class="expertio-reply">
						<?php comment_reply_link(array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
					</div>
    			</div>
            </div>
            <div class="tk-main-description">
				<?php if ($comment->comment_approved == '0') : ?>
					<p class="expertio-comment-moderation"><?php esc_html_e('Your comment is awaiting moderation.', 'expertio'); ?></p>
				<?php endif; ?>
				<?php comment_text(); ?>
			</div>
		</div>
		<?php
	}
}

/**
 * comments wrap start
 * @return slug
 */
if (!function_exists('expertio_comment_form_top')) {
	add_action('comment_form_top', 'expertio_comment_form_top');

	function expertio_comment_form_top() {
		// Adjust this to your needs:
		$output = '';
		$output .='<div class="tk-themeform__wrap"><fieldset>';

		echo do_shortcode( $output);
	}

}

/**
 * @count items in array
 * @return {}
 */
if (!function_exists('expertio_count_items')) {
    function expertio_count_items($items) {
        if( is_array($items) ){
			return count($items);
		} else{
			return 0;
		}
    }
}

/**
 * comments wrap start
 * @return slug
 */
if (!function_exists('expertio_comment_form')) {
	add_action('comment_form', 'expertio_comment_form');

	function expertio_comment_form() {
		$output = '';
		$output .= '</fieldset></div>';

		echo do_shortcode( $output );
	}

}

/**
 * @Change Reply link Class
 * @return sizes
 */
if (!function_exists('expertio_replace_reply_link_class')) {
    add_filter('comment_reply_link', 'expertio_replace_reply_link_class');

    function expertio_replace_reply_link_class($class) {
        $class = str_replace("class='comment-reply-link'", 'class="comment-reply-link tk-theme-btn"', $class);
        return $class;
    }
}

/**
 * @Enqueue admin scripts and styles.
 * @return{}
 */
if (!function_exists('expertio_admin_enqueue')) {

    function expertio_admin_enqueue($hook) {
        global $post;
        $protolcol = is_ssl() ? "https" : "http";
        $theme_version = wp_get_theme('expertio');

        wp_localize_script('expertio-admin-functions', 'scripts_vars', array(
			'ajax_nonce' 		=> wp_create_nonce('ajax_nonce'),
        ));
    }

    add_action('admin_enqueue_scripts', 'expertio_admin_enqueue', 10, 1);
}

/**
 * @Theme Editor/guttenberg Style
 * 
 */
if (!function_exists('expertio_add_editor_styles')) {

    function expertio_add_editor_styles() {
		global $theme_settings;
		$protocol = is_ssl() ? 'https' : 'http';
        $theme_version = wp_get_theme('expertio');
		$editor_css  = '';
		
		if (function_exists('fw_get_db_settings_option')) {
            $color_base = fw_get_db_settings_option('color_settings');
        }
		
		$site_colors 	= '#3377FF';
		
		if (!empty($site_colors)) {
			$editor_css  .= 'body.block-editor-page .editor-styles-wrapper a,
			body.block-editor-page .editor-styles-wrapper p a,
			body.block-editor-page .editor-styles-wrapper p a:hover,
			body.block-editor-page .editor-styles-wrapper a:hover,
			body.block-editor-page .editor-styles-wrapper a:focus,
			body.block-editor-page .editor-styles-wrapper a:active{color: '.$site_colors.';}';
			
			$editor_css  .= 'body.block-editor-page .editor-styles-wrapper blockquote:not(.blockquote-link),
							 body.block-editor-page .editor-styles-wrapper .wp-block-quote.is-style-large,
							 body.block-editor-page .editor-styles-wrapper .wp-block-quote:not(.is-large):not(.is-style-large),
							 body.block-editor-page .editor-styles-wrapper .wp-block-quote.is-style-large,
							 body.block-editor-page .editor-styles-wrapper .wp-block-pullquote, 
							 body.block-editor-page .editor-styles-wrapper .wp-block-quote, 
							 body.block-editor-page .editor-styles-wrapper .wp-block-quote:not(.is-large):not(.is-style-large),
							 body.block-editor-page .wp-block-pullquote, 
							 body.block-editor-page .wp-block-quote, 
							 body.block-editor-page .wp-block-verse, 
							 body.block-editor-page .wp-block-quote:not(.is-large):not(.is-style-large){border-color:'.$site_colors.';}';
		}
		
		$font_families	= array();
		$font_families[] = 'Outfit:400,500,600,700';
		$font_families[] = 'Open+Sans:400,600,700';
		
		 $query_args = array (
			 'family' => implode('%7C' , $font_families) ,
			 'subset' => 'latin,latin-ext' ,
        );

        $theme_fonts = add_query_arg($query_args , $protocol.'://fonts.googleapis.com/css');
		add_editor_style(esc_url_raw($theme_fonts));
		
		wp_enqueue_style('expertio-admin-google-fonts' , esc_url_raw($theme_fonts), array () , null);
		
		$editor_css .= "
		body.block-editor-page editor-post-title__input,
		body.block-editor-page .editor-post-title__block .editor-post-title__input
		{font: 700 1.125rem/1.4444444444em 'Outfit', sans-serif}";
		
		$editor_css .= "body.block-editor-page .editor-styles-wrapper{font: 400 1rem/1.625em 'Open Sans', sans-serif}";
		
		$editor_css .= "body.block-editor-page .editor-styles-wrapper{color: #0A0F26;}";
		$editor_css .= "body.block-editor-page editor-post-title__input,
		body.block-editor-page .editor-post-title__block .editor-post-title__input,
		body.block-editor-page .editor-styles-wrapper h1, 
				body.block-editor-page .editor-styles-wrapper h2, 
				body.block-editor-page .editor-styles-wrapper h3, 
				body.block-editor-page .editor-styles-wrapper h4, 
				body.block-editor-page .editor-styles-wrapper h5, 
				body.block-editor-page .editor-styles-wrapper h6 {font-family: 'Outfit', sans-serif}";
							   
		wp_enqueue_style( 'expertio-editor-style', get_template_directory_uri() . '/admin/css/expertio-editor-style.css', array(), $theme_version->get('Version'));
		wp_add_inline_style( 'expertio-editor-style', $editor_css );
		
    }

    add_action('enqueue_block_editor_assets', 'expertio_add_editor_styles');
}

/**
 * search type
 * @return slug
 */
if (!function_exists('expertio_custom_body_class')) {
	add_filter( 'body_class', 'expertio_custom_body_class' );
	function expertio_custom_body_class( $classes ) {
		global $servento_settings;
		$page_id 	= get_the_ID();
		$pages		= !empty($servento_settings['tb_dark_header']) ? $servento_settings['tb_dark_header'] : array();
		if ( is_page() && !empty($pages) && in_array($page_id,$pages) ) {
			$classes[] = 'tk-mainbodydark';
		}
		return $classes;
	}
}